@@ -1,14 +1,11 @@
 import re
 from typing import Optional
 
+from lxml import etree, html
+
 from draftjs_exporter.engines.base import Attr, DOMEngine
 from draftjs_exporter.types import HTML, Tag
 
-try:
-    from lxml import etree, html
-except ImportError:
-    pass
-
 NSMAP = {"xlink": "http://www.w3.org/1999/xlink"}
 
 RENDER_RE = re.compile(r"</?fragment>")
@@ -45,9 +42,7 @@ class DOM_LXML(DOMEngine):
 
     @staticmethod
     def render(elt: etree.Element) -> HTML:
-        return RENDER_RE.sub(
-            "", etree.tostring(elt, method="html", encoding="unicode")
-        )
+        return RENDER_RE.sub("", etree.tostring(elt, method="html", encoding="unicode"))
 
     @staticmethod
     def render_debug(elt: etree.Element) -> HTML:
